@@ -18,7 +18,7 @@ import onnx.numpy_helper  # type: ignore
 try:
     import onnxruntime as rt  # type: ignore
 except ImportError:
-    command = [sys.executable, '-m', 'pip', 'install', '--user', 'onnxruntime']
+    command = [sys.executable, '-m', 'pip', 'install', 'onnxruntime']
     print(Text(f"Installing onnxruntime by `{' '.join(command)}`, please wait for a moment..", style="bold magenta"))
     import subprocess
     subprocess.check_call(command)
@@ -28,6 +28,7 @@ except ImportError:
 import onnxsim.onnxsim_cpp2py_export as C
 from . import model_info
 from . import model_checking
+from . import version
 
 
 TensorShape = List[int]
@@ -174,7 +175,6 @@ def simplify(
     def parse_size(size: str) -> int:
         units = {"B": 1, "KB": 2**10, "MB": 2**20, "GB": 2**30, "TB": 2**40}
         size = size.upper()
-        #print("parsing size ", size)
         if not re.match(r' ', size):
             size = re.sub(r'([KMGT]?B)', r' \1', size)
         number, unit = [string.strip() for string in size.split()]
@@ -338,11 +338,12 @@ def main():
         "--no-large-tensor",
         help="Some ops like Tile and ConstantOfShape can produce large tensor and make the model size much larger. Specifying this flag to skip folding these ops, with loss of some optimization chances. It can be followed with a threshold, for example, --no-large-tensor 1M or --no-large-tensor 100KB.",
         type=str,
-        const='0B',
+        const='1KB',
         default=MAX_TENSOR_SIZE_THRESHOLD,
         nargs="?",
         dest="tensor_size_threshold",
     )
+    parser.add_argument('-v', '--version', action='version', version='onnxsim ' + version.version)
 
     args = parser.parse_args()
 
