@@ -249,6 +249,10 @@ std::vector<onnx::TensorProto> RunOp(onnx::ModelProto& model,
         input_names.end()) {
       continue;
     }
+    // skip "" which represents the unset optional input
+    if (input.empty()) {
+      continue;
+    }
     input_names.push_back(input);
     auto in_tp = FindInitializerByName(model, input);
     input_tps.push_back(in_tp);
@@ -260,6 +264,10 @@ std::vector<onnx::TensorProto> RunOp(onnx::ModelProto& model,
   }
   *op_model.mutable_graph()->add_node() = op;
   for (const auto& x : input_names) {
+    // skip "" which represents the unset optional input
+    if (x.empty()) {
+      continue;
+    }
     *op_model.mutable_graph()->add_input() = FindValueInfoProtoByName(model, x);
   }
   for (const auto& x : op.output()) {
@@ -338,17 +346,20 @@ bool ProduceLargeTensor(const onnx::ModelProto& model,
       for (const auto& dim : value_info.type().tensor_type().shape().dim()) {
         size *= dim.dim_value();
       }
-      if (size > threshold) {
-        return true;
+      if (size <= threshold) {
+        return false;
       }
     }
   }
-  return false;
+  // If the output is not in value_info, we assume it is large.
+  return true;
 }
 
 std::pair<std::vector<onnx::NodeProto>, std::vector<onnx::NodeProto>>
 GetConstantNodes(const onnx::ModelProto& model) {
-  std::vector<std::string> const_names;
+  // tensor with empty name("") represents the empty value of an optional input
+  // so "" should be treated as a name of a constant tensor.
+  std::vector<std::string> const_names{""};
   std::vector<onnx::NodeProto> const_nodes;
   std::vector<onnx::NodeProto> non_const_nodes;
   std::transform(
